import { StateContext, Store } from "@ngxs/store";
import { ErrorHandler } from "@angular/core";
import { Node, Entity, NodeEntity } from "./file-browser.model";
import { GenerateFileBrowser, GetNode, SelectNode, GenerateTreeLevels, GenerateHistory, ToggleFolder, SortNodes, SetOS } from "./file-browser.actions";
import { NodeSortingService } from "../services/node-sorting.service";
export interface FileBrowserStateModel {
    nodes: Node[];
    entities: Entity[];
    nodeEntity: NodeEntity[];
    currentNode: NodeEntity;
    selectedNode: NodeEntity;
    childNodes: NodeEntity[];
    history: NodeEntity[];
    sort: String;
    sidebar: Boolean;
    os: String;
    multiSelect: boolean;
}
export declare class FileBrowserState implements ErrorHandler {
    store: Store;
    nodeSorting: NodeSortingService;
    constructor(store: Store, nodeSorting: NodeSortingService);
    handleError(error: any): void;
    static getNodes(state: FileBrowserStateModel): Node[];
    static getNodeEntity(state: FileBrowserStateModel): NodeEntity[];
    static getChildNodes(state: FileBrowserStateModel): NodeEntity[];
    static getHistory(state: FileBrowserStateModel): NodeEntity[];
    static getSort(state: FileBrowserStateModel): String;
    static getSidebar(state: FileBrowserStateModel): Boolean;
    static getOS(state: FileBrowserStateModel): String;
    static getMultiSelect(state: FileBrowserStateModel): Boolean;
    generateFileBrowser({patchState}: StateContext<FileBrowserStateModel>, {nodes, entities}: GenerateFileBrowser): void;
    getNode({getState, patchState}: StateContext<FileBrowserStateModel>, {node}: GetNode): void;
    selectNode({getState, patchState}: StateContext<FileBrowserStateModel>, {node, multi, type}: SelectNode): void;
    unselectNode({getState, patchState}: StateContext<FileBrowserStateModel>): void;
    generateHistory({getState, patchState}: StateContext<FileBrowserStateModel>, {node}: GenerateHistory): void;
    generateTreeFirstLevel({getState, patchState}: StateContext<FileBrowserStateModel>): void;
    generateTreeLevels({getState, patchState}: StateContext<FileBrowserStateModel>, {level}: GenerateTreeLevels): void;
    toggleFolder({getState, patchState}: StateContext<FileBrowserStateModel>, {node}: ToggleFolder): void;
    sortNodes({getState, patchState}: StateContext<FileBrowserStateModel>, {sort}: SortNodes): void;
    showTree({getState, patchState}: StateContext<FileBrowserStateModel>): void;
    setOS({patchState}: StateContext<FileBrowserStateModel>, {os}: SetOS): void;
    openNodes({getState}: StateContext<FileBrowserStateModel>): void;
    deleteNodes({getState}: StateContext<FileBrowserStateModel>): void;
    downloadNodes({getState}: StateContext<FileBrowserStateModel>): void;
    propertiesNodes({getState}: StateContext<FileBrowserStateModel>): void;
}
